CREATE TABLE ERWPart_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     description               Long VarChar   ,
     note                      Long VarChar   ,
     logPhysFlag               Int   ,
     constraint PKERWPart_version Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWObject 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     created                   VarChar(254)   ,
     updated                   VarChar(254)   ,
     constraint PKERWObject Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWObject AS --Plasma for ERWObject
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWObject a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWPycOjtvs   -- ERWPhysicalObject_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     targetServerID            Int   ,
     objectTypeCode            Int   ,
     objectTypeName            VarChar(254)   ,
     inSchema                  DBOID   ,
     inLibrary                 DBOID   ,
     constraint PKERPycOjtvs Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWPhysObjProperty 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     propertyType              VarChar(254)   ,
     isString                  Int   ,
     isNumber                  Int   ,
     isReference               Int   ,
     stringVal                 Blob(1G) COMPACT    ,
     numberVal                 Int   ,
     blobVal                   Blob(1G) COMPACT    ,
     forPhysObject             DBOID   ,
     constraint PKERWPhysObjPrprty Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_EWhsbPpt AS --Plasma for ERWPhysObjProperty
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWPhysObjProperty a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWProperty 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     propertyType              VarChar(254)   ,
     count                     Int   ,
     datatype                  VarChar(254)   ,
     note                      Long VarChar   ,
     description               Long VarChar   ,
     elementIndex              Int   ,
     value                     Blob(10000000) COMPACT    ,
     forObject                 DBOID   ,
     forPart                   DBOID   ,
     forDomain                 DBOID   ,
     constraint PKERWProperty Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWProperty AS --Plasma for ERWProperty
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWProperty a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWPartition 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     partitionNo               Int   ,
     cardinality               Int   ,
     freePage                  Int   ,
     pctFree                   Int   ,
     pctActive                 Int   ,
     pctDrop                   Int   ,
     space                     Int   ,
     statsTime                 VarChar(254)   ,
     GBPCache                  Int   ,
     farIndRef                 Int   ,
     nearIndRef                Int   ,
     farOnPos                  Int   ,
     nearOffPos                Int   ,
     leafDist                  Int   ,
     chkFlag                   Int   ,
     checkRID                  VarChar(254)   ,
     pageSave                  Int   ,
     forTable                  DBOID   ,
     usedBy                    DBOID   ,
     constraint PKERWPartition Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWPartition AS --Plasma for ERWPartition
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWPartition a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWDataType 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     typeName                  VarChar(254)   ,
     constraint PKERWDataType Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWDataType AS --Plasma for ERWDataType
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWDataType a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWModelObject 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     objectID                  Int   ,
     objectName                VarChar(254)   ,
     objectType                VarChar(254)   ,
     description               Long VarChar   ,
     note                      Long VarChar   ,
     logPhysFlag               Int   ,
     validationRule            DBOID   ,
     constraint PKERWModelObject Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWModelObject AS --Plasma for ERWModelObject
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWModelObject a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWPropertyDefintn   -- ERWPropertyDefinition
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     isHidden                  Int   ,
     dataType                  VarChar(254)   ,
     defaultValue              VarChar(254)   ,
     ownerType                 VarChar(254)   ,
     library                   DBOID   ,
     constraint PKERWPropertyDfntn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWProprtyDfntn AS --Plasma for ERWPropertyDefinition
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWPropertyDefintn a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWAttribute 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     parentAttribute           VarChar(254)   ,
     carrierRelationshp        VarChar(254)   ,
     ofEntity                  DBOID   ,
     constraint PKERWAttribute Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWAttribute AS --Plasma for ERWAttribute
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWAttribute a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWColumn 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     sequenceNumber            Int   ,
     loggedLOB                 Int   ,
     compactLOB                Int   ,
     nullsAllowed              Int   ,
     localTypeCode             Int   ,
     localTypeName             VarChar(254)   ,
     localPrecision            Int   ,
     localLength               Int   ,
     defaultValue              DBOID   ,
     usesDomain                DBOID   ,
     forTable                  DBOID   ,
     view                      DBOID   ,
     constraint PKERWColumn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWColumn AS --Plasma for ERWColumn
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWColumn a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWTable_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     dontGenerate              Int   ,
     audit                     Int   ,
     usingHashing              Int   ,
     targetServerID            Int   ,
     icon                      Blob(1G) COMPACT    ,
     alterDTS                  VarChar(254)   ,
     chkFlag                   Int   ,
     chkRID                    VarChar(254)   ,
     dataCaptureFlag           Int   ,
     editProc                  VarChar(254)   ,
     pctPages                  Int   ,
     pctRowComp                Int   ,
     recordLength              Int   ,
     validProc                 VarChar(254)   ,
     restrictOnDrop            Int   ,
     CCSID                     VarChar(254)   ,
     numPartitions             Int   ,
     randUpdateFlag            Int   ,
     logPrimary                Int   ,
     logSecondary              Int   ,
     logFileSize               Int   ,
     initByForeignSrc          Int   ,
     notLoggedInitially        Int   ,
     catalogDBID               VarChar(254)   ,
     catalogOBID               VarChar(254)   ,
     keyOBID                   VarChar(254)   ,
     numPages                  Int   ,
     partitionKey              VarChar(254)   ,
     longIn                    DBOID   ,
     indexIn                   DBOID   ,
     storedIn                  DBOID   ,
     inSchema                  DBOID   ,
     containedBy               DBOID   ,
     inRelationship            DBOID   ,
     hasPartitioningKey        DBOID   ,
     constraint PKERWTable_version Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWEntity_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     icon                      Blob(1G) COMPACT    ,
     inRelationship            DBOID   ,
     inDiagram                 DBOID   ,
     inSubtypeSet              DBOID   ,
     constraint PKERWEntity_versin Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWSubjectAre_vrsn   -- ERWSubjectArea_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     diagram                   DBOID   ,
     constraint PKERWSubjctAr_vrsn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWSynonym 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     genSyn                    Int   ,
     synDB                     VarChar(254)   ,
     forTable                  DBOID   ,
     constraint PKERWSynonym Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWSynonym AS --Plasma for ERWSynonym
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWSynonym a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWDiagram_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     modelType                 Int   ,
     client                    DBOID   ,
     pDBMS                     DBOID   ,
     inLibrary                 DBOID   ,
     constraint PKERWDiagram_versn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWLibrary_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     inLibrary                 DBOID   ,
     constraint PKERWLibrary_versn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWDBMS_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     DBMSType                  VarChar(254)   ,
     majorVersion              Int   ,
     minorVersion1             Int   ,
     minorVersion2             Int   ,
     diagram                   DBOID   ,
     constraint PKERWDBMS_version Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWView_version 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     query                     VarChar(254)   ,
     where                     Long VarChar   ,
     groupBy                   VarChar(254)   ,
     orderBy                   VarChar(254)   ,
     withCheck                 Int   ,
     body                      Long VarChar   ,
     distinct                  Int   ,
     having                    Long VarChar   ,
     force                     Int   ,
     orReplace                 Int   ,
     constraintName            VarChar(254)   ,
     wOption                   Int   ,
     derivedBy                 DBOID   ,
     diagram                   DBOID   ,
     containedBy               DBOID   ,
     constraint PKERWView_version Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWGraphicFeature 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     featureType               VarChar(254)   ,
     featureValue              VarChar(254)   ,
     propertyType              VarChar(254)   ,
     parentObject              DBOID   ,
     parentPart                DBOID   ,
     pStoredDisplay            DBOID   ,
     hasProperty               DBOID   ,
     constraint PKERWGraphicFeatur Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWGraphicFeatr AS --Plasma for ERWGraphicFeature
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWGraphicFeature a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWStoredDisplay 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     subjectArea               DBOID   ,
     constraint PKERWStoredDisplay Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWStoredDisply AS --Plasma for ERWStoredDisplay
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWStoredDisplay a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWTextBlock 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     diagram                   DBOID   ,
     constraint PKERWTextBlock Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWTextBlock AS --Plasma for ERWTextBlock
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWTextBlock a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWRelationship 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     diagram                   DBOID   ,
     constraint PKERWRelationship Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWRelationship AS --Plasma for ERWRelationship
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWRelationship a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWDepndncyRltnshp   -- ERWDependencyRelationship
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     cardinality               VarChar(254)   ,
     manyToManyAssoc           VarChar(254)   ,
     parentChildVrbPhrs        VarChar(254)   ,
     childParentVrbPhrs        VarChar(254)   ,
     parentEntity              DBOID   ,
     childEntity               DBOID   ,
     constraint PKERDnnylnh Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_RDnnylnh AS --Plasma for ERWDependencyRelationship
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWDepndncyRltnshp a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWSubType 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     isComplete                Int   ,
     hasDiscriminator          DBOID   ,
     parentEntity              DBOID   ,
     constraint PKERWSubType Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWSubType AS --Plasma for ERWSubType
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWSubType a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWDefaultValue 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     serverValue               VarChar(254)   ,
     clientValue               VarChar(254)   ,
     library                   DBOID   ,
     forColumn                 DBOID   ,
     constraint PKERWDefaultValue Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWDefaultValue AS --Plasma for ERWDefaultValue
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWDefaultValue a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWDerivedRel 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     qualifier                 VarChar(254)   ,
     sequenceNum               Int   ,
     constraint PKERWDerivedRel Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWDerivedRel AS --Plasma for ERWDerivedRel
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWDerivedRel a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWValidValue 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     clientValue               VarChar(254)   ,
     serverValue               VarChar(254)   ,
     library                   DBOID   ,
     validationRule            DBOID   ,
     constraint PKERWValidValue Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWValidValue AS --Plasma for ERWValidValue
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWValidValue a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWValidationRule 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     isClient                  Int   ,
     isServer                  Int   ,
     NOT                       Int   ,
     QUOTE                     Int   ,
     generateAs                Int   ,
     uniqueNamingCount         Int   ,
     serverExpression          VarChar(254)   ,
     minValue                  VarChar(254)   ,
     maxValue                  VarChar(254)   ,
     library                   DBOID   ,
     forPart                   DBOID   ,
     forModelObj               DBOID   ,
     constraint PKERWValidationRul Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWValidationRl AS --Plasma for ERWValidationRule
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWValidationRule a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWTriggerTemplate 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     templateCode              Long VarChar   ,
     RIType                    VarChar(254)   ,
     library                   DBOID   ,
     diagram                   DBOID   ,
     constraint PKERWTriggerTemplt Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWTriggerTmplt AS --Plasma for ERWTriggerTemplate
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWTriggerTemplate a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWSchemaTemplate 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     isPreScript               Int   ,
     constraint PKERWSchemaTemplat Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWSchemaTemplt AS --Plasma for ERWSchemaTemplate
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWSchemaTemplate a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWPrePostTrigger 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     templateCode              Long VarChar   ,
     isPreScript               Int   ,
     inLibrary                 DBOID   ,
     constraint PKERWPrePostTriggr Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWPrePostTrggr AS --Plasma for ERWPrePostTrigger
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWPrePostTrigger a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWTableTrigger 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     triggerCode               Long VarChar   ,
     triggerType               Int   ,
     triggerOld                VarChar(254)   ,
     triggerNew                VarChar(254)   ,
     triggerFire               Int   ,
     triggerScope              Int   ,
     table                     DBOID   ,
     constraint PKERWTableTrigger Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWTableTrigger AS --Plasma for ERWTableTrigger
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWTableTrigger a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWClient 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     version                   VarChar(254)   ,
     diagram                   DBOID   ,
     constraint PKERWClient Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWClient AS --Plasma for ERWClient
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWClient a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWDatabase_versin   -- ERWDatabase_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     catalogDBID               VarChar(254)   ,
     codePage                  VarChar(254)   ,
     driveLetter               Int   ,
     ROShare                   VarChar(254)   ,
     CCSID                     VarChar(254)   ,
     bpName                    VarChar(254)   ,
     constraint PKERWDatabase_vrsn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWNodeGroup_versn   -- ERWNodeGroup_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     allNodes                  Int   ,
     numNodes                  Int   ,
     onNodes                   VarChar(254)   ,
     constraint PKERWNodeGrop_vrsn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWBufferPool_vrsn   -- ERWBufferPool_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     bufPoolNo                 Int   ,
     bufSize                   Int   ,
     bufType                   Int   ,
     usageIntent               VarChar(254)   ,
     allNodes                  Int   ,
     extendedStorage           Int   ,
     exceptOnNodes             VarChar(254)   ,
     onNodeGroups              VarChar(254)   ,
     constraint PKERWBufferPl_vrsn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWStorageGrp_vrsn   -- ERWStorageGroup_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     password                  VarChar(254)   ,
     pwdFlag                   Int   ,
     space                     Int   ,
     spaceDate                 VarChar(254)   ,
     defType                   VarChar(254)   ,
     reqdSpace                 Int   ,
     volume                    VarChar(254)   ,
     vcat                      VarChar(254)   ,
     constraint PKERWStorgGrp_vrsn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWTblIndxSpc_vrsn   -- ERWTableIndexSpace_version
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     freePage                  Int   ,
     pctFree                   Int   ,
     numParts                  Int   ,
     GBPCache                  Int   ,
     closeRule                 Int   ,
     dsetPassword              VarChar(254)   ,
     dsetPwdFlag               Int   ,
     deferRule                 Int   ,
     subPages                  Int   ,
     compressFlag              Int   ,
     implicit                  Int   ,
     locksize                  VarChar(254)   ,
     nActive                   Int   ,
     nTables                   Int   ,
     pageSize                  Int   ,
     segSize                   Int   ,
     space                     Int   ,
     status                    Int   ,
     lockMax                   Int   ,
     maxValue                  Int   ,
     maxRows                   Int   ,
     lockPart                  Int   ,
     largeTS                   Int   ,
     CCSID                     VarChar(254)   ,
     keepInMain                Int   ,
     usageIntent               Int   ,
     TSType                    Int   ,
     extentSize                Int   ,
     prefetchSize              Int   ,
     overhead                  VarChar(254)   ,
     transferRate              Int   ,
     managedBy                 Int   ,
     Using                     VarChar(254)   ,
     part                      VarChar(254)   ,
     bpName                    VarChar(254)   ,
     refersToSG                DBOID   ,
     refersToBP                DBOID   ,
     storesIndex               DBOID   ,
     constraint PKEWbIdScvs Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE TABLE ERWIndex 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     isUnique                  Int   ,
     clustered                 Int   ,
     numLeafs                  Int   ,
     numLevels                 Int   ,
     clusterRatio              Int   ,
     catalogDBID               VarChar(254)   ,
     catalogISOBID             VarChar(254)   ,
     catalogOBID               VarChar(254)   ,
     pageSize                  Int   ,
     space                     Int   ,
     whereNotNull              Int   ,
     indexType                 Int   ,
     pieceSize                 Int   ,
     dataRcdsInIndx            Int   ,
     distinctValues            Int   ,
     closeRule                 Int   ,
     dsetPassword              VarChar(254)   ,
     deferRule                 Int   ,
     subPages                  Int   ,
     Using                     VarChar(254)   ,
     part                      VarChar(254)   ,
     bpName                    VarChar(254)   ,
     genIndex                  Int   ,
     table                     DBOID   ,
     containedBy               DBOID   ,
     storedIn                  DBOID   ,
     constraint PKERWIndex Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWIndex AS --Plasma for ERWIndex
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWIndex a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWIndexColumn 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     isAscending               Int   ,
     sequenceNumber            Int   ,
     forIndex                  DBOID   ,
     memberColumn              DBOID   ,
     constraint PKERWIndexColumn Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWIndexColumn AS --Plasma for ERWIndexColumn
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWIndexColumn a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWAlternateKey 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     partitionKeyFor           DBOID   ,
     constraint PKERWAlternateKey Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWAlternateKey AS --Plasma for ERWAlternateKey
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWAlternateKey a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

CREATE TABLE ERWRIRule 
   ( OID                       DBOID NOT NULL  ,
     OVer                      DBOVER NOT NULL  ,
     parentDeleteRule          VarChar(254)   ,
     parentUpdateRule          VarChar(254)   ,
     parentInsertRule          VarChar(254)   ,
     childDeleteRule           VarChar(254)   ,
     childUpdateRule           VarChar(254)   ,
     childInsertRule           VarChar(254)   ,
     belongsToRel              DBOID   ,
     constraint PKERWRIRule Primary Key( OID, OVer ) )
	   IN TOOLS ;

CREATE VIEW Pl_ERWRIRule AS --Plasma for ERWRIRule
  SELECT
	 a.*,
	 m.sourceOID,
	 m.sourceOVer
  FROM
	 ERWRIRule a, ManyPtrTable m
  WHERE
	 m.targetOID=a.OID AND m.targetOVer=a.OVer AND
	   m.classAttrib='ADViewRoot.plasma';

